GoConqr has a new look! Let us know what you think.

Flashcards

med chem 2 final exam

lola_smily English 5.0Average rating 5.0 out of 5 (1 rating) 200 cards 1,965 views

med chem 2 final exam

Cards in this deck (200)

  1. 1—heparin
    anticoagulant
    parenteral
    mucopolysaccharide
    source: pig lungs, pig intestinal mucosa
    isolated from liver
    high/low (higher affinity) molecular weight
    acidic: carboxylic acid and sulfate groups
    anion: at physiological pH
    given as Na+ salt/poor GI absorption
    IV/SQ (not IM: cause hematoma)
    -MOA: accelerates binding of antithrombin to thrombin (inhibit it + inhibit factor 10a)
    -metabolism (partially): depolymerization, desulfuration --> inactive mtb (liver)
    -prolonged effect if: renal, hepatic dysfunction
    -SE: hemorrhage, alopecia (after 3-4m), thrombocytopenia
    if high dose (>50mg) --> heparin like effects
    -antidote: protamine sulfate
    heparin anticoagulant parenteral mucopolysaccharide source: pig lungs, pig intestinal mucosa isolated from liver high/low (higher affinit...
  2. 2—warfarin
    anticoagulant
    oral
    4-hydroxycoumarin derivative
    racemic mixture: S(-)>R(+)
    given Na+, K+ salts
    bioavailability: 100%
    onset of action: 12-48h --> slow
    DOA: 2-5d
    MOA: vitamin K antagonist (inhibit vit K epoxide reductase, vit K quinone reductase, gamma carboxylation) --> reduce factors 10,9,7,2
    metabolism: S--> CYP2C9/ R--> CYP2C19
    2'-hydroxywarfarin (active)
    caution in pregnancy: crosses placenta
    SE: hemorrhage, skin rash, nausea, thrombocytopenia, diarrhea, skin necrosis
    antidote: blood transfusion, give factors
    warfarin anticoagulant oral 4-hydroxycoumarin derivative racemic mixture: S(-)>R(+) given Na+, K+ salts bioavailability: 100% onset of...
  3. 3—vitamin Kvitamin K
  4. 4—hemiketal form of warfarin
    similar to hemiketal form of vit K
    compete for same enzyme
    hemiketal form of warfarin similar to hemiketal form of vit K compete for same enzyme
  5. 5—hemiketal form of vit K
    share similarities with hemiketal form of warfarin
    hemiketal form of vit K share similarities with hemiketal form of warfarin
  6. 6—(S)-7-hydroxywarfarin
    metabolite of warfarin by CYP2C9
    (S)-7-hydroxywarfarin metabolite of warfarin by CYP2C9
  7. 7—(S)-6-hydroxywarfarin
    metabolite of warfarin by CYP2C9
    (S)-6-hydroxywarfarin metabolite of warfarin by CYP2C9
  8. 8—2'-hydroxywarfarin
    metabolite of warfarin
    active
    2'-hydroxywarfarin metabolite of warfarin active
  9. 9—(R)-warfarin
    can be metabolized by CYP2C19 on C7
    (R)-warfarin can be metabolized by CYP2C19 on C7
  10. 10—anisindione
    anticoagulant
    oral
    1,3-indandione derivative
    onset of action: 12-48h --> slow
    DOA: 2-5d
    MOA: same as warfarin
    alkaline urine (red-orange color)
    anisindione anticoagulant oral 1,3-indandione derivative onset of action: 12-48h --> slow DOA: 2-5d MOA: same as warfarin alkaline uri...
  11. 11—phenindione
    anticoagulant
    oral
    1,3-indandione derivative
    onset of action: 12-48h --> slow
    DOA: 2-5d
    MOA: same as warfarin
    alkaline urine (red-orange color)
    phenindione anticoagulant oral 1,3-indandione derivative onset of action: 12-48h --> slow DOA: 2-5d MOA: same as warfarin alkaline uri...
  12. 12—citric acid
    in vitro anticoagulant
    chelate Ca2+ (inhibit factor 4)
    citric acid in vitro anticoagulant chelate Ca2+ (inhibit factor 4)
  13. 13—EDTA
    in vitro anticoagulant
    chelate Ca2+ (inhibit factor 4)
    EDTA in vitro anticoagulant chelate Ca2+ (inhibit factor 4)
  14. 14—aspirin (ASA)
    antiplatelet
    inhibit COX 1 irreversibly --> inhibit PGI2 and TXA2
    acidic
    active as such
    GI disturbance
    aspirin (ASA) antiplatelet inhibit COX 1 irreversibly --> inhibit PGI2 and TXA2 acidic active as such GI disturbance
  15. 15—trifusal
    antiplatelet
    inhibit COX 1
    inhibit PDE
    active as such
    metabolized to: deacetylated form (2-hydroxy-4-trifluromethylbenzoic acid HTB) --> active
    trifusal antiplatelet inhibit COX 1 inhibit PDE active as such metabolized to: deacetylated form (2-hydroxy-4-trifluromethylbenzoic acid ...
  16. 16—sulfinpyrazone
    antiplatelet
    inhibit COX 1 reversibly
    metabolism: inactive metabolites--> p-hydroxysulfinpyrazone, sulfone, p-hydroxysulfide, sulfide
    sulfinpyrazone antiplatelet inhibit COX 1 reversibly metabolism: inactive metabolites--> p-hydroxysulfinpyrazone, sulfone, p-hydroxysu...
  17. 17—dipyridamole
    antiplatelet
    inhibit PDE (phosphodiesterase) --> increase cAMP --> inhibit release of aggregating agent
    inhibit adenosine reuptake --> increase cAMP
    dipyridamole antiplatelet inhibit PDE (phosphodiesterase) --> increase cAMP --> inhibit release of aggregating agent inhibit adenos...
  18. 18—cilostazole
    antiplatelet
    quinolinone derivative
    inhibit PDE3A
    inhibit adenosine reuptake
    orally active
    well absorbed
    increase absorption with high fat meal
    metabolism: CYP3A4, CYP2C19--> active: DHC, HC
    cilostazole antiplatelet quinolinone derivative inhibit PDE3A inhibit adenosine reuptake orally active well absorbed increase absorption ...
  19. 19—3,4-dehydrocilostazol
    antiplatelet
    major active metabolite of cilostazol by CYP3A4
    3,4-dehydrocilostazol antiplatelet major active metabolite of cilostazol by CYP3A4
  20. 20—4'-hydroxycilostazol
    antiplatelet
    minor active metabolite of cilostazol by CYP2C19
    4'-hydroxycilostazol antiplatelet minor active metabolite of cilostazol by CYP2C19
  21. 21—ticlopidine
    antiplatelet
    thienopyridine derivative
    prodrug
    orally active
    MOA: ADP pathway inhibitor, inhibit GP2b/3a receptor
    t1/2: 24-36h --> long
    onset of action: 48h --> slow
    metabolism (liver): 2-keto metabolite, thiol metabolite (active), M5 and M6 (toxic)
    SE: neutropenia, thrombocytopenia, skin rash, GI effects
    ticlopidine antiplatelet thienopyridine derivative prodrug orally active MOA: ADP pathway inhibitor, inhibit GP2b/3a receptor t1/2: 24-36...
  22. 22—clopidogrel
    antiplatelet
    thienopyridine derivative
    prodrug
    orally active
    MOA: ADP pathway inhibitor
    t1/2= 24-36h --> long
    metabolism: hydrolyzation of the thiol--> active metabolite (bind to P2Y and prevent binding of ADP--> t1/2= 8h)
    SE: rare neutropenia, thrombocytopenia, GI effects
    clopidogrel antiplatelet thienopyridine derivative prodrug orally active MOA: ADP pathway inhibitor t1/2= 24-36h --> long metabolism: ...
  23. 23—prasugrel
    antiplatelet
    thienopyridine derivative
    orally active
    metabolism: hydrolyzed to thiolactone then thiol --> active
    used in combination with aspirin
    like clopidogrel: non competitive antagonist of P2Y12 (irreversibly)--> block ADP for the life of platelets (10days)
    prasugrel antiplatelet thienopyridine derivative orally active metabolism: hydrolyzed to thiolactone then thiol --> active used in com...
  24. 24—eptifibatide
    antiplatelet
    GP2b/3a receptor antagonist
    cyclic heptapeptide (KGD sequence)
    IV
    t1/2= 2.5h --> short
    excretion: renal
    eptifibatide antiplatelet GP2b/3a receptor antagonist cyclic heptapeptide (KGD sequence) IV t1/2= 2.5h --> short excretion: renal
  25. 25—tirofiban
    antiplatelet
    GP2b/3a receptor antagonist
    non peptide (distance btw COO- and NH+ is identical to RGD sequence--> compete with fibrinogen)
    t1/2= 2h --> short
    IV
    excretion: renal (unchanged)
    tirofiban antiplatelet GP2b/3a receptor antagonist non peptide (distance btw COO- and NH+ is identical to RGD sequence--> compete with...
  26. 26—epoprostenol
    antiplatelet
    prostaglandin metabolite of arachidonic acid
    PGI2
    potent vasodilator
    IV
    t1/2= 3-6min
    increase in cAMP--> decrease release of aggregation mediator
    epoprostenol antiplatelet prostaglandin metabolite of arachidonic acid PGI2 potent vasodilator IV t1/2= 3-6min increase in cAMP--> dec...
  27. 27Abciximabantiplatelet
    GP2b/3a receptor antagonist
    monoclonal antibody
    IV
    short t1/2= 30min
  28. 28urokinasefibrinolytic agent
    from human urine and renal cells
    act on plasminogen to produce plasmin
    nonantigenic
  29. 29streptokinasefibrinolytic agent
    from hemolytic streptococci
    generates more plasmin than urokinase (via 2 steps)
    allergic reactions (due to Ab formation)
  30. 30anistriplasefibrinolytic agent
    prodrug
    2nd generation plasminogen activator
    acetylated-plasminogen-streptokinase-activator complex (APSAC)
    p-anisoyl derivative of Lys-plasminogen-streptokinase
  31. 31alteplasefibrinolytic agent
    2nd generation plasminogen activator
    tissue plasminogen activator (tPA)
    formed by recombinant DNA techniques
  32. 32reteplasefibrinolytic agent
    3rd generation plasminogen activator
    modified alteplase
    less affinity to fibrin clot than alteplase
  33. 33ananasefibrinolytic agent
    mixture of proteolytic enzymes
    from pineapple plant
    non selective to fibrin clot
    anti-inflammatory agent
    cheap
  34. 34tenecteplasefibrinolytic agent
    3rd generation plasminogen activator
    composed of 527a.a.: 103 a.a: Thr--> Asp
    117 a.a: Asp--> Glu
    296-299 a.a: Lys-His-Arg-Arg--> Ala (x4)
    15X higher fibrin selectivity
    elimination: hepatically
  35. 35—prostaglandin
    prostanoic acid derivative
    must have: 15-alpha OH
    13-14 trans double bond
    alpha/beta chain: trans
    A,B,C,D,E,F,G,H,I (differ in C9-11)
    prostaglandin prostanoic acid derivative must have: 15-alpha OH 13-14 trans double bond alpha/beta chain: trans A,B,C,D,E,F,G,H,I (differ...
  36. 36—PGDPGD
  37. 37—PGE
    PGE1: dilation of bronchiol smooth muscle
    PGE2: dilation of bronchiol smooth muscle, dilation of blood vessel
    PGE PGE1: dilation of bronchiol smooth muscle PGE2: dilation of bronchiol smooth muscle, dilation of blood vessel
  38. 38—PGF2alpha
    constriction of bronchiol smooth muscle, constriction of blood vessels
    PGF2alpha constriction of bronchiol smooth muscle, constriction of blood vessels
  39. 39—PGG/PGHPGG/PGH
  40. 40—PGI2 (prostacyclin)
    from PGH2
    inhibit platelet aggregation
    dilation of blood vessels
    PGI2 (prostacyclin) from PGH2 inhibit platelet aggregation dilation of blood vessels
  41. 41—TXA2
    from PGH2
    aggregation of platelet
    constriction of blood vessels
    TXA2 from PGH2 aggregation of platelet constriction of blood vessels
  42. 42—arachidonic acid
    cis 5,8,11,14-eicosatetraenoic acid
    precursor of prostaglandins by COX
    and leukotrienes by LOX
    arachidonic acid cis 5,8,11,14-eicosatetraenoic acid precursor of prostaglandins by COX and leukotrienes by LOX
  43. 43—acetanilide
    NSAID
    removed from market
    form: acetaminophen/ aniline --> toxic
    SE: methemoglobenemia, skin rash, jaundice
    acetanilide NSAID removed from market form: acetaminophen/ aniline --> toxic SE: methemoglobenemia, skin rash, jaundice
  44. 44—phenacetin
    NSAID
    removed from market
    form: acetaminophen/ aniline --> toxic
    SE: nephritis, carcinogenecity in rats
    phenacetin NSAID removed from market form: acetaminophen/ aniline --> toxic SE: nephritis, carcinogenecity in rats
  45. 45—acetaminophen
    NSAID
    antipyretic, analgesic
    little antiinflammatory activity
    MOA: reversible inhibitor of COX3 (brain)
    metabolism: by CYP2E1--> N-acetylmidoquinone (reactive metabolite)
    by glucuronidation and sulfation
    acetaminophen NSAID antipyretic, analgesic little antiinflammatory activity MOA: reversible inhibitor of COX3 (brain) metabolism: by CYP2...
  46. 46—N-acetylimidoquinone (NAPQI)
    metabolite of acetaminophen
    metabolism: N-acetylcysteine, glutathione (renal excretion), hepatic protein (hepatic necrosis)
    N-acetylimidoquinone (NAPQI) metabolite of acetaminophen metabolism: N-acetylcysteine, glutathione (renal excretion), hepatic protein (he...
  47. 47—salicylic acid
    metabolite of aspirin
    salicylic acid metabolite of aspirin
  48. 48—aspirin
    NSAIDs
    MOA: irreversibly inhibits COX1 (10-100X)> COX2 enzymes by acetylating serine 530
    pKa=3.49
    salicylate anion essential for activity
    stable in dry condition
    -absorbtion: upper small intestine (depend on gastric pH, tablet formulation, presence of food in stomach)
    high pH: increase ionization--> more soluble --> less absorbed
    buffering agent: if high dose --> decrease absorption
    if low dose --> increase absorption
    -formulation: tablet of small particles --> absorbed faster
    absorption from rectal--> slow
    absorption after topical--> fast
    -metabolism: hydrolyzed to salicylic acid and acetic acid (in aqueous solution) by glucuronidation, glycine conjugation
    stable in: alcohol, glycerin
    -SE: GI disturbance, salicylism (high dose) --> tinnitis, fatal --> respiratory failure (medullary depression) at high dose, Reye's syndrome in children with viral infection :influenza, chicken pox (encephalopathy, liver damage, violent headache), GI: (PGs--> cryoprotective for the gastric mucosa) gastric distress/bleeding, acute hemorrhage (dose dependent)
    aspirin NSAIDs MOA: irreversibly inhibits COX1 (10-100X)> COX2 enzymes by acetylating serine 530 pKa=3.49 salicylate anion essential f...
  49. 49—salicylamide
    NSAIDs
    analgesic and antipyretic (not antiinflammatory)
    fairly stable to heat and moisture
    poor water solubility
    for aspirin sensitive patients
    no gastric irritation
    more CNS effect than aspirin
    metabolism: inactive --> not hydrolyzed to salicylic acid
    salicylamide NSAIDs analgesic and antipyretic (not antiinflammatory) fairly stable to heat and moisture poor water solubility for aspirin...
  50. 50—salsalate
    NSAIDs
    dimer of salicylic acid
    insoluble in gastric acid juice
    -metabolism: partially hydrolized in intestine --> 2 salicylic acid molecules (site of absorption), forms less salicylic acid than aspirin (15%)
    -less gastric upset than aspirin
    salsalate NSAIDs dimer of salicylic acid insoluble in gastric acid juice -metabolism: partially hydrolized in intestine --> 2 salicyli...
  51. 51—diflunisal
    NSAIDs
    analgesic, little antipyretic
    insoluble in water
    slightly more potent than aspirin
    t1/2= longer than aspirin
    -metabolism: ether/ester glucuronide
    not metabolized to salicylic acid--> no gastric upset
    -SE: few, GI disturbances, diarrhea, skin reaction
    diflunisal NSAIDs analgesic, little antipyretic insoluble in water slightly more potent than aspirin t1/2= longer than aspirin -metabolis...
  52. 52—mesalamine
    NSAID
    5-amino salicylic acid
    metabolite of sulfasalazine and olsalazine
    MOA: inhibit COX in the bowel mucosa--> decrease colonic inflammation
    inhibit LOX --> decrease leukotrienes
    mesalamine NSAID 5-amino salicylic acid metabolite of sulfasalazine and olsalazine MOA: inhibit COX in the bowel mucosa--> decrease co...
  53. 53—sulfasalazine
    prodrug
    precursor of mesalamine
    metabolized by azo reductase
    sulfasalazine prodrug precursor of mesalamine metabolized by azo reductase
  54. 54—olsalazine
    prodrug
    precursor to mesalamine in GI tract
    by bacterial flora
    act locally (not systemically)
    olsalazine prodrug precursor to mesalamine in GI tract by bacterial flora act locally (not systemically)
  55. 55—phenylbutazone
    NSAIDs
    4-butyl-1,2-diphenyl-3,5-pyrazolidinedione
    not a drug of choice
    analgesic, antipyretic, antiinflammatory
    slight water soluble
    -to treat: painful symptoms of gout (uricosuric), rheumatoid arthritis, bursitis
    -metabolism: to oxyphenbutazone (active NSAID), glucuronidation, gamma-hydroxyphenylbutazone (uricosuric), gamma-ketophenylbutazone (antiinflammatory)
    -SE: abdominal discomfort, nausea, skin rashes, peptic ulcer, blood disorder
    -contraindicated: in children <14y --> due to Na+ retention
    phenylbutazone NSAIDs 4-butyl-1,2-diphenyl-3,5-pyrazolidinedione not a drug of choice analgesic, antipyretic, antiinflammatory slight wat...
  56. 56—oxyphenbutazone
    NSAIDs
    metabolite of phenylbutazone
    same potency as phenylbutazone
    same SE but with less GI effect
    oxyphenbutazone NSAIDs metabolite of phenylbutazone same potency as phenylbutazone same SE but with less GI effect
  57. 57—indomethacin
    NSAIDs
    arylalkonic acid
    indole acetic acid derivative
    most potent (analgesic agent: more than aspirin,
    antipyretic agent: more than phenylbutazone,
    antiiflammatory agent: more than phenylbutazone)
    weak water soluble
    light sensitive
    rapid absorption after oral dose
    highly bound to plasma protein
    metabolized to inactive
    SE: GI disturbance, headache, vertigo, dizziness, severe depression, suicide attempts
    indomethacin NSAIDs arylalkonic acid indole acetic acid derivative most potent (analgesic agent: more than aspirin, antipyretic agent: mo...
  58. 58—sulindac
    NSAIDs
    arylalkonic acid
    indene derivative
    prodrug
    water soluble (at alkaline pH)
    stable at alkaline aqueous solution, air, 100C
    t1/2= 8h (sulfide t1/2=16h)
    absorbed: as sulfoxide
    -metabolism: to sulfide derivative (in the cirulation)
    -analgesic activity: equal to indomethacin
    -antiinflammatory/antipyretic activity: less than indomethacin
    -for: rheumatoid arthritis, osteoarthritis, gouty arthritis, ankylosing spondylitis
    -SE: gastric irritation, headache, vertigo, dizziness, skin rash
    sulindac NSAIDs arylalkonic acid indene derivative prodrug water soluble (at alkaline pH) stable at alkaline aqueous solution, air, 100C ...
  59. 59—sulfide
    NSAID
    active metabolite of sulindac
    t1/2= 16h
    sulfide NSAID active metabolite of sulindac t1/2= 16h
  60. 60—tolmetin sodium
    NSAIDs
    arylalkonic acid
    N-methylpyrrole acetic acid derivative
    very water soluble
    free acid form--> water insoluble
    t1/2= 1h --> short
    -potency: more than phenylbutazone, less than indomethacin
    -for: different types of arthritis
    -metabolism: to inactive metabolites
    -SE: GI disturbance (less than aspirin)
    tolmetin sodium NSAIDs arylalkonic acid N-methylpyrrole acetic acid derivative very water soluble free acid form--&gt; water insoluble t1...
  61. 61—diclofenac sodium
    NSAIDs
    arylalkonic acid
    most used NSAID in the world
    poor water soluble
    complete absorption after oral dose
    highly bound to plasma protein
    50% bioavailabilty (first pass)
    analgesic, antipyretic, antiinflammatory
    analgesic/antipyretic agent: more potent than aspirin
    more potent than indomethacin
    -MOA: inhibit COX1 and LOX
    inhibit arachidonic acid release, stimulate uptake --> decrease AA availability
    -for: rheumatoid arthritis, osteoarthritis, ankylosing spondylitis
    -metabolite: 4'OH (30-40%)--> weak act.
    diclofenac sodium NSAIDs arylalkonic acid most used NSAID in the world poor water soluble complete absorption after oral dose highly boun...
  62. 62—etodolac
    NSAIDs
    arylalkonic acid
    tetrahydropyrano acetic acid derivative
    rapid GI absorption
    highly bound to plasma protein
    -antiinflammatory: more potent than aspirin, sulindac
    less potent than indomethacin
    -racemate--> S(+) active
    -metabolized: to inactive
    etodolac NSAIDs arylalkonic acid tetrahydropyrano acetic acid derivative rapid GI absorption highly bound to plasma protein -antiinflamma...
  63. 63—nabumetone
    NSAIDs
    prodrug
    non acid derivative
    water insoluble
    analgesic: less active than aspirin
    -metabolism (rapid): acetic acid derivative --> 6-methoxynaphtalene-2-acetic acid (6MNA) (38%) --> active
    -less gastric damage (absorbed as ketone, converted to 6MNA in circulation)
    -for: osteoarthritis, rheumatoid arthritis
    nabumetone NSAIDs prodrug non acid derivative water insoluble analgesic: less active than aspirin -metabolism (rapid): acetic acid deriva...
  64. 64—6MNA
    active metabolite of nabumetone
    in circulation
    6MNA active metabolite of nabumetone in circulation
  65. 65—ibuprofen
    NSAIDs
    arylpropionic acid
    2(p-isobutylphenyl)propionic acid
    most used NSAID
    orally active
    -same effect as aspirin (less SE)
    racemic mixture--> S(+) more potent than R(-)
    -for: osteoarthritis, rheumatoid arthritis, antipyretic, mild to moderate pain
    -metabolism: to inactive metabolite
    give ibufenac (active)--> less potent, hepatotoxic
    -excretion: (+) isomer
    ibuprofen NSAIDs arylpropionic acid 2(p-isobutylphenyl)propionic acid most used NSAID orally active -same effect as aspirin (less SE) rac...
  66. 66—ibufenac
    p-isobutylphenyl acetic acid
    active form of ibuprofen
    less potent
    hepatotoxic
    ibufenac p-isobutylphenyl acetic acid active form of ibuprofen less potent hepatotoxic
  67. 67—fenoprofen calcium
    NSAIDs
    arylpropionic acid derivative
    2(3'-phenoxyphenyl)propionic acid
    slightly water soluble
    rapid absorption after oral dose
    highly bound to plasma protein
    Na+ and Ca2+ salts (less hygroscopic): similar pharmacokinetic
    -antiinflammatory: less potent than ibuprofen
    PG synthesis inhibitor: more potent than aspirin, less potent than indomethacin
    metabolism: to inactive metabolites
    fenoprofen calcium NSAIDs arylpropionic acid derivative 2(3'-phenoxyphenyl)propionic acid slightly water soluble rapid absorption after o...
  68. 68—ketoprofen
    NSAIDs
    arylpropionic acid derivative)
    2(3'-benzoylphenyl)propionic acid
    insoluble in water and many organic solvent
    rapidly completely absorbed after oral dose
    -MOA: inhibit COX, inhibit LOX, lysosomal mb stabilizer--> decrease release of lysosomal enzymes--> decrease tissue damage
    -for: osteoarthritis, rheumatoid arthritis, antipyretic, mild to moderate pain, dysmenorrheal
    -metabolism: glucuronidation, carbonyl reduction, ring hydroxylation
    ketoprofen NSAIDs arylpropionic acid derivative) 2(3'-benzoylphenyl)propionic acid insoluble in water and many organic solvent rapidly co...
  69. 69—naproxen
    NSAIDs
    arylpropionic acid derivative
    2(6'-methoxy-2'-naphtyl)propionic acid
    both enantiomer marketed: (-)--> anaprox (naproxen Na+)
    complete GI absorption after oral dose
    99% bound to plasma protein
    -PG synthesis inhibitor: more potent than aspirin, phenylbutazone, ibuprofen
    -antiinflammatory: less potent than indomethacin
    -analgesic/antipyretic: more potent than phenylbutazone, aspirin, indomethacin
    -ulceration: less--> than aspirin, indomethacin, ketoprofen, tolmetin
    more--> than sulindac
    -for: different types of arthritis, ankylosing spondylitis, tenditis, bursitis, mild-moderate pain
    -metabolism: to inactive--> glucuronidation and O-demethylation
    -SE: GI irritation, nausea, dizziness
    naproxen NSAIDs arylpropionic acid derivative 2(6'-methoxy-2'-naphtyl)propionic acid both enantiomer marketed: (-)--&gt; anaprox (naproxe...
  70. 70—suprofen
    NSAIDs
    arylpropionic acid
    2(4'(2'thienyl carbonyl)phenyl)propionic acid
    removed from market because renal failure
    reintroduced as mydriatic agent: for ophtalmic use --> inhibit intraoperative miosis
    suprofen NSAIDs arylpropionic acid 2(4'(2'thienyl carbonyl)phenyl)propionic acid removed from market because renal failure reintroduced a...
  71. 71—flubiprofen
    NSAIDs
    arylpropionic acid derivative
    2(2'-fluoro-4'-biphenyl)propionic acid
    Na+ salt: topical for ophtalmic use(ocufen)--> mydriatic agent (inhibit intraoperative miosis)
    free acid form: oral use (ansaid)--> top prescribed use (osteo, rheumatoid arthritis)
    well GI absorption after oral dose
    99% bound to plasma protein
    antiinflammatory: more potent than aspirin, phenylbutazone
    antipyretic: more potent than aspirin
    analgesic: more potent than ibuprofen
    -metabolized: to inactive metabolite--> glucuronidation, sulfation, 4'OH, 3',4'OH, 3'OH, 4'-OCH3
    flubiprofen NSAIDs arylpropionic acid derivative 2(2'-fluoro-4'-biphenyl)propionic acid Na+ salt: topical for ophtalmic use(ocufen)--&gt;...
  72. 72—ketorolac
    NSAIDs
    arylpropionic acid derivative
    5-benzoyl-2,3-dihydro-1-pyrrolidine-1-carboxylic acid
    orally active
    highly bound to plasma protein
    analgesic activity: comparable to morphine
    for: ophtalmic use, injection, for short term management of pain
    ketorolac NSAIDs arylpropionic acid derivative 5-benzoyl-2,3-dihydro-1-pyrrolidine-1-carboxylic acid orally active highly bound to plasma...
  73. 73—oxaprozin
    NSAIDs
    arylpropionic acid derivative (not alpha methyl acetic acid derivative)
    complete absorption after oral dose
    highly bound to plasma proteins
    t1/2= 59h--> long
    onset: rapid
    long acting
    antiinflammatory: equal to aspirin
    -for: short, long term treatment of osteoarthritis, rheumatoid arthritis
    -metabolism: (in liver) p-hydroxylation --> active
    -SE: skin rash, mild photosensitivity
    oxaprozin NSAIDs arylpropionic acid derivative (not alpha methyl acetic acid derivative) complete absorption after oral dose highly bound...
  74. 74—fenamic acid
    NSAIDs
    arylanthranilic acid derivatives
    antiiflammatory/analgesic activities: little or no advantage over salicylates
    -MOA (like salicylates): COX inhibition
    -SE (like salicylates): GI disturbances, headache, dizziness, skin rash, transient hepatic and renal abnormalities
    fenamic acid NSAIDs arylanthranilic acid derivatives antiiflammatory/analgesic activities: little or no advantage over salicylates -MOA (...
  75. 75—mefenamic acid
    NSAIDs
    N(2',3'-xylyl)anthranilic acid
    Orally active
    water insoluble (except at high pH)
    Highly bound to plasma proteins
    analgesic (mainly), anti-inflammatory
    t1/2=2-4h --> short
    for short term pain management
    Metabolized: to inactive metabolites--> ester glucuronide, hydroxymethyl and dicarboxylic acid
    mefenamic acid NSAIDs N(2',3'-xylyl)anthranilic acid Orally active water insoluble (except at high pH) Highly bound to plasma proteins an...
  76. 76—meclofenamate sodium
    NSAID
    arylanthranilic acid derivative
    meclofenamate sodium NSAID arylanthranilic acid derivative
  77. 77—meclofenamic acid
    NSAID
    arylanthranilic acid derivative
    Rapidly, completely absorbed after oral dose
    Highly bound to plasma proteins
    t1/2= 2-4h --> short
    -potency: 25% more than mefenamic acid
    -Metabolism: oxidation of methyl, ring hydroxylation and monodehalogenation
    meclofenamic acid NSAID arylanthranilic acid derivative Rapidly, completely absorbed after oral dose Highly bound to plasma proteins t1/2...
  78. 78—meclofenamic acid metabolite
    active
    by oxidation of methyl
    meclofenamic acid metabolite active by oxidation of methyl
  79. 79—piroxicam
    NSAIDs
    oxicam
    4-hydroxy-1,2-benzothiazine carboxamides
    pKa=4-6 (acidic)
    orally active
    highly bound to plasma protein
    more potent than fenamate
    -potency: piroxicam> indomethacin> ibuprofen
    Long t ½ 38 hrs
    -anti-inflammatory agent: more potent than aspirin and phenylbutazone, equal to indomethacin
    analgesic agent: less potent than indomethacin, equal to fenoprofen, ibuprofen, naproxen and phenylbutazone
    -MOA: Inhibitor of COX, lysosomal enzymes release and migration of polymorphonuclear cells into inflammatory sites, inhibits collagen induced platelet aggregation
    -Metabolism: pyridine and aromatic benzothiazine ring hydroxylation (inactive metabolites)
    -SE: Same like other NSAIDs
    -for (most commonly used NSAIDs): osteoarthritis and rheumatoid arthritis, ankylosing spondylitis
    piroxicam NSAIDs oxicam 4-hydroxy-1,2-benzothiazine carboxamides pKa=4-6 (acidic) orally active highly bound to plasma protein more poten...
  80. 80—meloxicam
    NSAIDs
    oxicam
    4-hydroxy-1,2-benzothiazine carboxamides
    pKa=4-6 (acidic)
    orally active
    highly bound to plasma protein
    more potent than fenamate
    -MOA: selectivity to COX2
    -metabolism: CYP2C9 (extensively) and CYP3A4 (less)
    -SE: Less GI side effects
    meloxicam NSAIDs oxicam 4-hydroxy-1,2-benzothiazine carboxamides pKa=4-6 (acidic) orally active highly bound to plasma protein more poten...
  81. 81—celecoxib
    First NSAID marketed as selective COX-2 inhibitor
    Diarylpyrazole derivative
    does not contain carboxylate anion
    Orally active
    t1/2= 11h
    -metabolizm: into inactive metabolites
    -SE: Less GI disturbances than other NSAIDs, causes edema and hypertension (caution in case of CHF)
    celecoxib First NSAID marketed as selective COX-2 inhibitor Diarylpyrazole derivative does not contain carboxylate anion Orally active t1...
  82. 82—valdecoxib
    NSAIDs
    selective COX2 inhibitor
    oxazole moiety
    Orally active
    t1/2= 7-8h
    -metabolizm: by CYP3A4 and CYP2D6
    (substrate and inhibitor of these enzymes)
    valdecoxib NSAIDs selective COX2 inhibitor oxazole moiety Orally active t1/2= 7-8h -metabolizm: by CYP3A4 and CYP2D6 (substrate and inhib...
  83. 83—parecoxib
    NSAIDs
    selective COX2 inhibitor
    Prodrug
    IV and IM (only parenterally administered coxib
    -metabolism: rapidly metabolized (in vivo) --> valdecoxib
    -analgesic: more potent than ketorolac
    parecoxib NSAIDs selective COX2 inhibitor Prodrug IV and IM (only parenterally administered coxib -metabolism: rapidly metabolized (in vi...
  84. 84—etoricoxib
    NSAIDs
    selective COX2 inhibitor
    Orally active
    t1/2= 22h --> long
    -metabolism: by CYP3A4 (but is not inhibitor)--> 6'-hydroxymethyl and 1-N-oxide , glucuronides-->inactive
    -excretion: mainly renal elimination as metabolites
    etoricoxib NSAIDs selective COX2 inhibitor Orally active t1/2= 22h --&gt; long -metabolism: by CYP3A4 (but is not inhibitor)--&gt; 6'-hy...
  85. 85—prontosil
    antimetabolite
    sulfonamide
    prodrug
    ozo moiety
    only active in vivo
    metabolism: to sulfanilamide
    poor water soluble
    forms crystalluria
    prontosil antimetabolite sulfonamide prodrug ozo moiety only active in vivo metabolism: to sulfanilamide poor water soluble forms crystal...
  86. 86—sulfanilamide
    antimetabolite
    aniline sulfonamides
    White
    colorless
    bitter tasting crystals
    weak acids
    water insoluble
    -More soluble in alkaline solutions than acidic
    -available as Na+ salts --> moderately water soluble
    -structurally analogues of PABA --> compete with dehydropteroate synthase (get incorporated in folic acid synthesis)
    -do not affect mammalian cells
    -cross placenta
    -metabolism (in liver): to inactive
    -Activity against: gram-ve/ gram +ve, E.coli, nocardia.
    -SE: urinary tract disturbances, hypersensitivity, hematopoietic disturbances
    rare: aplastic and hemolytic anemia, agranulocytosis, thrombocytopenia
    kernicterus and jaundice, anorexia, nausea, vomiting and diarrhea
    -DDI: Potentiation of sulfonylurea oral hypoglycemics, oral anticoagulants and hydantoin (due to displacement from plasma proteins)
    -Drug resistance: altered enzyme (major), overproduction of PABA, reduced cellular reuptake of drug, enhanced drug inactivation
    sulfanilamide antimetabolite aniline sulfonamides White colorless bitter tasting crystals weak acids water insoluble -More soluble in alk...
  87. 87—sulfamethoxazole
    antimetabolite
    Sulfonamide
    rapidly absorbed and rapidly eliminated
    t1/2= 10h --> short
    ppb: 70%
    highly water soluble--> rarely produce crystalluria
    sulfamethoxazole antimetabolite Sulfonamide rapidly absorbed and rapidly eliminated t1/2= 10h --&gt; short ppb: 70% highly water soluble-...
  88. 88—sulfisoxazole
    antimetabolite
    Sulfonamide
    rapidly absorbed and rapidly eliminated
    t1/2= 6h --> short
    ppb: 90%
    highly water soluble--> rarely produce crystalluria
    sulfisoxazole antimetabolite Sulfonamide rapidly absorbed and rapidly eliminated t1/2= 6h --&gt; short ppb: 90% highly water soluble--&gt...
  89. 89—Sulfadiazine
    antimetabolite
    Sulfonamide
    rapidly absorbed and rapidly eliminated
    t1/2= 10-17h
    most active
    ppb: 45% --> low
    relatively water soluble --> crystalluria
    Sulfadiazine antimetabolite Sulfonamide rapidly absorbed and rapidly eliminated t1/2= 10-17h most active ppb: 45% --&gt; low relatively w...
  90. 90—sulfamethizole
    antimetabolite
    Sulfonamide
    rapidly absorbed and rapidly eliminated
    t1/2= 9h -->short
    ppb: 90% --> highly bound
    sulfamethizole antimetabolite Sulfonamide rapidly absorbed and rapidly eliminated t1/2= 9h --&gt;short ppb: 90% --&gt; highly bound
  91. 91—sulfasalazine
    antimetabolite
    Sulfonamide
    poorly absorbed
    prodrug
    for: treating GI infections
    metabolizm: by bacteria flora
    sulfasalazine antimetabolite Sulfonamide poorly absorbed prodrug for: treating GI infections metabolizm: by bacteria flora
  92. 92—sulfapyridine
    toxic mtb of sulfasalazine
    absorption: from GI
    excretion: in urine
    sulfapyridine toxic mtb of sulfasalazine absorption: from GI excretion: in urine
  93. 93—mesalamine
    5-para-amino salycilic acid
    active mtb of sulfasalazine
    mesalamine 5-para-amino salycilic acid active mtb of sulfasalazine
  94. 94—sulfadoxine
    antimetabolite
    Sulfonamide
    rapidly absorbed (from GI) but very slowly eliminated
    ppb: 98% --> highly bound
    t ½ 7-10 days--> extraordinary
    sulfadoxine antimetabolite Sulfonamide rapidly absorbed (from GI) but very slowly eliminated ppb: 98% --&gt; highly bound t ½ 7-10 days--...
  95. 95—Silver sulfadiazine
    antimetabolite
    sulfonamide
    Topically administered
    their salts are very potent antimicrobial in the treatment of burns, scald & wound infection
    Silver sulfadiazine antimetabolite sulfonamide Topically administered their salts are very potent antimicrobial in the treatment of burns...
  96. 96—sulfacetamide
    antimetabolite
    sulfonamide
    Topically administered
    their salts are very potent antimicrobial in the treatment of burns, scald & wound infection
    sulfacetamide antimetabolite sulfonamide Topically administered their salts are very potent antimicrobial in the treatment of burns, scal...
  97. 97—Mafenide
    antimetabolite
    not a true sulfonamide
    Topically administered
    Mafenide antimetabolite not a true sulfonamide Topically administered
  98. 98—trimethoprim
    antimetabolite
    Not a sulfonamide
    Trimethoxy benzyl diaminopyridine, Bacteriostatic
    -MOA: Potent inhibitor of DHF reductase, Similar antibacterial spectrum to sulfonamides
    Higher affinity to bacterial DHF reductase than mammalian
    -Mostly compounded with sulfamethoxazole TMP/SMX (Cotrimoxazole)
    oral and IV
    -potency: TMP (20-50X) > SMX
    -absorption: TMP well absorbed from GI
    -ppb: 60-70%
    -concentrated in prostatic fluid and vaginal fluid--> most used in UTI
    -excretion: mainly renal, small amounts biliary
    -SE:- Long term use: antifolate effects, folate deficiency, megaloblastic anemia, granulocytopenia, leucopenia (reversed by folinic acid), nausea, vomiting, fever, renal damage, skin rashes, CNS disturbances
    trimethoprim antimetabolite Not a sulfonamide Trimethoxy benzyl diaminopyridine, Bacteriostatic -MOA: Potent inhibitor of DHF reductase, ...
  99. 99—polymyxin
    bacterial cell membrane disrupting agent
    Cyclic polypeptides (by Bacillus polymyxa, soil bacteria)
    polymyxin sulfate B (B1 and B2) Polymyxin E (E1, E2) --> colistin
    Bactericidal cationic detergent (5 + charges)
    -MOA: React with – charged phospholipids-->disrupt cell mb --> creates holes --> cell leakage
    -active against most Gram – (not against Gram + and anaerobics)
    -Pseudomonnas aeruginosa (only): elevated levels of Mg2+ and Ca2+ --> decrease activity
    -absorption: GI (not well), topically, IV and IM, (found in ophthalmic, otic)
    -for: bacterial diarrhea
    -poor distribution (don't enter CSF)
    -excretion:renal via GF
    -SE: topically (few), orally (high dose): nausea and vomiting ,IV: nephro and neurotoxicity (accumulates in renal tubules)
    Large dose: damage to mammalian cell membranes --> inhibit NMJ --> respiratory paralysis
    -DDI: Aminoglycosides + polymyxins--> increase risk of respiratory/renal dysfunction
    NMJ blockers + polymyxins--> increase effect of NMJ
    -Use of polymyxins--> overgrowth of non-susceptible--> superinfection
    polymyxin bacterial cell membrane disrupting agent Cyclic polypeptides (by Bacillus polymyxa, soil bacteria) polymyxin sulfate B (B1 and ...
  100. 100—daptomycin
    bacterial cell membrane disrupting agent
    Novel cyclic lipopeptide antibiotic
    from Streptomyces sp.
    Consists of 13 a.a.
    bactericidal (dose dependant)
    -MOA: on Gram + (via acyl tail--> membrane depolarization),
    disrupts bacterial plasma mb function without penetrating into cytoplasm
    -MIC (minimal inhibitory concentration): for susceptible strains is 4X< vancomycin
    -post-antibiotic effect (PAE)
    -Synergism with gentamicin against staph. and enterococci
    IV
    ppb: 90%
    t1/2= 6.5-32h
    -excretion: mainly renal (80%)--> 2/3 intact
    -SE: Constipation, myopathy (dose dependent), GI discomfort, nausea, diarrhea, skin rash, headache, insomnia
    daptomycin bacterial cell membrane disrupting agent Novel cyclic lipopeptide antibiotic from Streptomyces sp. Consists of 13 a.a. bacteri...
  101. 101—6-aminopenicillanic acid (6-APA)
    beta-lactam
    fermentation derived
    not active: very minimal activity
    after acylation --> active compound (penicillin)
    6-aminopenicillanic acid (6-APA) beta-lactam fermentation derived not active: very minimal activity after acylation --&gt; active compoun...
  102. 102—penam
    beta lactam antibiotic
    penam beta lactam antibiotic
  103. 103—penem
    beta lactam antibiotic
    2,3-dihydrothiazole
    penem beta lactam antibiotic 2,3-dihydrothiazole
  104. 104—carbapenem
    beta lactam antibiotic
    2,3-dihydro-1H-pyrrole
    carbapenem beta lactam antibiotic 2,3-dihydro-1H-pyrrole
  105. 105—cefem
    beta lactam antibiotic
    3,6-dihydro-2H-1,3-thiazine
    cefem beta lactam antibiotic 3,6-dihydro-2H-1,3-thiazine
  106. 106—monobactam
    beta lactam antibiotic
    monobactam beta lactam antibiotic
  107. 107—carbacephems
    beta lactam antibiotic
    1,2,3,4-tetrahydropyridine
    carbacephems beta lactam antibiotic 1,2,3,4-tetrahydropyridine
  108. 108—oxacephems
    beta lactam antibiotic
    3,6-dihydro-2H-1,3-oxazine
    oxacephems beta lactam antibiotic 3,6-dihydro-2H-1,3-oxazine
  109. 109—Pen G
    benzyl penicillin
    beta lactam antibiotic
    fermentation derived
    must be kept dry
    Na and K salts are crystalline, hygroscopic and water soluble
    orally and parenterally
    stable for a long time unless in solution
    improved acid stability (by addition of e- withdrawing grp on side chain)
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Pen G benzyl penicillin beta lactam antibiotic fermentation derived must be kept dry Na and K salts are crystalline, hygroscopic and wate...
  110. 110—Pen V
    phenoxy methyl penicillin
    beta lactam antibiotic
    must be kept dry
    Na and K salts are crystalline, hygroscopic and water soluble
    orally and parenterally
    stable for a long time unless in solution
    improved acid stability (by addition of e- withdrawing grp on side chain)
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Pen V phenoxy methyl penicillin beta lactam antibiotic must be kept dry Na and K salts are crystalline, hygroscopic and water soluble ora...
  111. 111—methicillin
    beta lactam antibiotic
    semi-synthetic
    penicillinase resistant (bulky group on diortho)
    parenteral
    contains e-donating groups --> not acid resistant
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: Nephritis / hypersensitivity / GI disturbances / neurotoxicity (seizures)
    methicillin beta lactam antibiotic semi-synthetic penicillinase resistant (bulky group on diortho) parenteral contains e-donating groups ...
  112. 112—nafcillin
    beta lactam antibiotic
    semi-synthetic
    penicillinase resistant (bulky group on diortho)
    parenteral
    contains e-donating groups --> not acid resistant
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    nafcillin beta lactam antibiotic semi-synthetic penicillinase resistant (bulky group on diortho) parenteral contains e-donating groups --...
  113. 113—oxacillin
    beta lactam antibiotic
    semi-synthetic
    penicillinase resistant
    improved acid stability
    oral
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hepatitis / hypersensitivity / GI disturbances / neurotoxicity (seizures)
    oxacillin beta lactam antibiotic semi-synthetic penicillinase resistant improved acid stability oral -excretion: renally by tubular secre...
  114. 114—cloxacillin
    beta lactam antibiotic
    semi-synthetic
    penicillinase resistant
    improved acid stability
    oral
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    cloxacillin beta lactam antibiotic semi-synthetic penicillinase resistant improved acid stability oral -excretion: renally by tubular sec...
  115. 115—dicloxacillin
    beta lactam antibiotic
    semi-synthetic
    penicillinase resistant
    improved acid stability
    oral
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    dicloxacillin beta lactam antibiotic semi-synthetic penicillinase resistant improved acid stability oral -excretion: renally by tubular s...
  116. 116—carbenizillin
    beta lactam antibiotic
    semi-synthetic
    carboxypenicillin
    penicillinase sensitive
    extended spectrum : antipseudomonas
    parenteral
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    carbenizillin beta lactam antibiotic semi-synthetic carboxypenicillin penicillinase sensitive extended spectrum : antipseudomonas parente...
  117. 117—carbenicillin phenyl
    beta lactam antibiotic
    semi-synthetic
    carboxypenicillin
    penicillinase sensitive
    extended spectrum : antipseudomonas
    parenteral
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    carbenicillin phenyl beta lactam antibiotic semi-synthetic carboxypenicillin penicillinase sensitive extended spectrum : antipseudomonas ...
  118. 118—carbenicillin indanyl
    beta lactam antibiotic
    semi-synthetic
    carboxypenicillin
    penicillinase sensitive
    extended spectrum : antipseudomonas
    parenteral
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    carbenicillin indanyl beta lactam antibiotic semi-synthetic carboxypenicillin penicillinase sensitive extended spectrum : antipseudomonas...
  119. 119—ticarcillin
    beta lactam antibiotic
    semi-synthetic
    carboxypenicillin
    penicillinase sensitive
    extended spectrum : antipseudomonas
    parenteral
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    ticarcillin beta lactam antibiotic semi-synthetic carboxypenicillin penicillinase sensitive extended spectrum : antipseudomonas parentera...
  120. 120—azlocillin
    beta lactam antibiotic
    semi-synthetic
    ureidopenicillin
    penicillinase sensitive
    extended spectrum : antipseudomonas
    parenteral
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    azlocillin beta lactam antibiotic semi-synthetic ureidopenicillin penicillinase sensitive extended spectrum : antipseudomonas parenteral ...
  121. 121—mezlocillin
    beta lactam antibiotic
    semi-synthetic
    ureidopenicillin
    penicillinase sensitive
    extended spectrum : antipseudomonas
    parenteral
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    mezlocillin beta lactam antibiotic semi-synthetic ureidopenicillin penicillinase sensitive extended spectrum : antipseudomonas parenteral...
  122. 122—piperacillin
    beta lactam antibiotic
    semi-synthetic
    ureidopenicillin
    penicillinase sensitive
    extended spectrum : antipseudomonas
    parenteral
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    piperacillin beta lactam antibiotic semi-synthetic ureidopenicillin penicillinase sensitive extended spectrum : antipseudomonas parentera...
  123. 123—Ampicillin
    beta lactam antibiotic
    alpha-aminobenzylpenicillin
    semi-synthetic
    penicillinase sensitive
    broad spectrum
    oral
    improved acid stability
    excreted renally by tubular secretion
    MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Ampicillin beta lactam antibiotic alpha-aminobenzylpenicillin semi-synthetic penicillinase sensitive broad spectrum oral improved acid st...
  124. 124—amoxicillin
    beta lactam antibiotic
    alpha amino-p-hydroxybenzylpenicillin
    semi-synthetic
    penicillinase sensitive
    broad spectrum
    oral
    improved acid stability
    -excretion: renally by tubular secretion
    -MOA : cell wall inhibitor - inhibit PBPs, the cross linking of peptidoglycan matrix/ activate autolytic enzymes : degrade the already formed cell wall
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    amoxicillin beta lactam antibiotic alpha amino-p-hydroxybenzylpenicillin semi-synthetic penicillinase sensitive broad spectrum oral impro...
  125. 125—Bacampicillin
    beta lactam antibiotic
    penicillin prodrug
    hydrolyzed by non specific esterase --> unstable products that form active free carboxylic acid
    SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Bacampicillin beta lactam antibiotic penicillin prodrug hydrolyzed by non specific esterase --&gt; unstable products that form active fre...
  126. 126—Pivampicillin
    beta lactam antibiotic
    penicillin prodrug
    hydrolyzed by non specific esterase --> unstable products that form active free carboxylic acid
    SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Pivampicillin beta lactam antibiotic penicillin prodrug hydrolyzed by non specific esterase --&gt; unstable products that form active fre...
  127. 127—Talampicillin
    beta lactam antibiotic
    penicillin prodrug
    hydrolyzed by non specific esterase --> unstable products that form active free carboxylic acid
    SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Talampicillin beta lactam antibiotic penicillin prodrug hydrolyzed by non specific esterase --&gt; unstable products that form active fre...
  128. 128—Pen G procaine
    beta lactam antibiotic
    amine salt of Pen G
    low water solubility
    given IM : local depot: slow dissolution and release --> prolong blood levels
    -excretion: renally by tubular secretion
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Pen G procaine beta lactam antibiotic amine salt of Pen G low water solubility given IM : local depot: slow dissolution and release --&gt...
  129. 129—Pen G benzathine
    beta lactam antibiotic
    diamine salt of Pen G
    very water insoluble
    given IM : local depot: slow dissolution and release --> prolong blood levels for more than a week
    -excretion: renally by tubular secretion
    -SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Pen G benzathine beta lactam antibiotic diamine salt of Pen G very water insoluble given IM : local depot: slow dissolution and release -...
  130. 130—Clavulanic acid
    beta lactamase inhibitors
    weak affinity to PBPs
    high affinity to beta lactamase
    irreversible beta lactamase inhibitor (adjunct therapy)
    produced from streptomyces clavuligeris
    1-oxopenam
    lack 6-amino group
    has 2-hydroxyethylidene moiety
    formulated with amoxicillin
    SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Clavulanic acid beta lactamase inhibitors weak affinity to PBPs high affinity to beta lactamase irreversible beta lactamase inhibitor (ad...
  131. 131—Sulbactam
    beta lactamase inhibitor
    weak affinity to PBPs
    high affinity to beta lactamase
    irreversible beta lactamase inhibitor (adjunct therapy)
    semi-synthetic
    1,1-dioxopenicillanic acid
    formulated with ampicillin
    SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Sulbactam beta lactamase inhibitor weak affinity to PBPs high affinity to beta lactamase irreversible beta lactamase inhibitor (adjunct t...
  132. 132—Tazobactam
    beta lactamase inhibitor
    weak affinity to PBPs
    high affinity to beta lactamase
    irreversible beta lactamase inhibitor (adjunct therapy)
    semi-synthetic
    1,1-dioxopenicillanic acid
    formulated with pipericillin
    SE: hypersensitivity / GI disturbances / neurotoxicity (seizures)
    Tazobactam beta lactamase inhibitor weak affinity to PBPs high affinity to beta lactamase irreversible beta lactamase inhibitor (adjunct ...
  133. 133—Cephalosporin C
    beta lactam antibiotic
    Isolated from C.acremonium
    Not potent enough to be clinically as an antibiotic
    Precursor to develop useful derivatives
    Cephalosporin C beta lactam antibiotic Isolated from C.acremonium Not potent enough to be clinically as an antibiotic Precursor to develo...
  134. 134—7-ACA
    beta lactam antibiotic
    7-aminocephalosporanic acid
    formed by the removal of the side chain from cephalosporin C
    analogous to 6-APA
    used to prepare semi-synthetic analogs
    Its 7-phenylglycine derivatives are orally active
    7-ACA beta lactam antibiotic 7-aminocephalosporanic acid formed by the removal of the side chain from cephalosporin C analogous to 6-APA ...
  135. 135—7-ADCA
    beta lactam antibiotic
    7-Amino-3-deacetoxy-cephalosporanic acid
    metabolite of pen V
    reduced acetoxy methyl of 7-ACA
    Its analogs are orally active
    7-ADCA beta lactam antibiotic 7-Amino-3-deacetoxy-cephalosporanic acid metabolite of pen V reduced acetoxy methyl of 7-ACA Its analogs ar...
  136. 136—Cephapirin
    beta lactam antibiotic
    first generation cephalosporin
    parenteral agent
    sodium salt
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cephapirin beta lactam antibiotic first generation cephalosporin parenteral agent sodium salt MOA : inhibit cell wall synthesis/similar t...
  137. 137—Cefazolin
    beta lactam antibiotic
    first generation cephalosporin
    parenteral agent
    sodium salt
    5 membered ring (thiadiazole) --> increase potency
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefazolin beta lactam antibiotic first generation cephalosporin parenteral agent sodium salt 5 membered ring (thiadiazole) --&gt; increas...
  138. 138—Cephalexin
    beta lactam antibiotic
    first generation cephalosporin
    oral agent because it contains an alpha amino benzyl substituent
    HCl salt
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cephalexin beta lactam antibiotic first generation cephalosporin oral agent because it contains an alpha amino benzyl substituent HCl sal...
  139. 139—Cefadroxil
    beta lactam antibiotic
    first generation cephalosporin
    oral agent because it contains a p-hydroxybenzyl substituent
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefadroxil beta lactam antibiotic first generation cephalosporin oral agent because it contains a p-hydroxybenzyl substituent MOA : inhib...
  140. 140—Cephradine
    beta lactam antibiotic
    first generation cephalosporin
    oral and parenteral agent
    it contains an alpha amino benzyl substituent
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cephradine beta lactam antibiotic first generation cephalosporin oral and parenteral agent it contains an alpha amino benzyl substituent ...
  141. 141—Cefamandole nafate
    beta lactam antibiotic
    second generation cephalosporin
    parenteral agent
    contains NMTT --> bleeding problems and disulfiram side effects
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefamandole nafate beta lactam antibiotic second generation cephalosporin parenteral agent contains NMTT --&gt; bleeding problems and dis...
  142. 142—Cefonicid
    beta lactam antibiotic
    second generation cephalosporin
    parenteral agent
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefonicid beta lactam antibiotic second generation cephalosporin parenteral agent MOA : inhibit cell wall synthesis/similar to penicillin...
  143. 143—Cefuroxime
    beta lactam antibiotic
    second generation cephalosporin
    parenteral agent
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefuroxime beta lactam antibiotic second generation cephalosporin parenteral agent MOA : inhibit cell wall synthesis/similar to penicilli...
  144. 144—Cefoxitin
    beta lactam antibiotic
    second generation cephalosporin
    parenteral agent
    Cephamycin : produced by Streptomyces species
    posses 7 alpha methoxy substituent => more resistance to beta lactamases
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefoxitin beta lactam antibiotic second generation cephalosporin parenteral agent Cephamycin : produced by Streptomyces species posses 7 ...
  145. 145—Cefotetan
    beta lactam antibiotic
    second generation cephalosporin
    parenteral agent
    contains NMTT --> bleeding problems and disulfiram side effects
    Cephamycin : produced by Streptomyces species
    posses 7 alpha methoxy substituent => more resistance to beta lactamases
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefotetan beta lactam antibiotic second generation cephalosporin parenteral agent contains NMTT --&gt; bleeding problems and disulfiram s...
  146. 146—Cefmetazole
    beta lactam antibiotic
    second generation cephalosporin
    parenteral agent
    contains NMTT --> bleeding problems and disulfiram side effects
    Cephamycin : produced by Streptomyces species
    posses 7 alpha methoxy substituent => more resistance to beta lactamases
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefmetazole beta lactam antibiotic second generation cephalosporin parenteral agent contains NMTT --&gt; bleeding problems and disulfiram...
  147. 147—Cefaclor
    beta lactam antibiotic
    second generation cephalosporin
    oral agent because it contains an alpha amino benzyl substituent
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefaclor beta lactam antibiotic second generation cephalosporin oral agent because it contains an alpha amino benzyl substituent MOA : in...
  148. 148—Loracarbef
    beta lactam antibiotic
    second generation cephalosporin
    oral agent because it contains an alpha amino benzyl substituent
    carba analogue of cefaclor : sulfur atom replaced by carbon --> less potent
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Loracarbef beta lactam antibiotic second generation cephalosporin oral agent because it contains an alpha amino benzyl substituent carba ...
  149. 149—Cefprozil
    beta lactam antibiotic
    second generation cephalosporin
    oral agent because it contains a p-hydroxybenzyl substituent
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefprozil beta lactam antibiotic second generation cephalosporin oral agent because it contains a p-hydroxybenzyl substituent MOA : inhib...
  150. 150—Cefotaxime
    beta lactam antibiotic
    third generation cephalosporin
    parenteral agent
    contains an alkoxyimino substituent => resistant to beta lactamases
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefotaxime beta lactam antibiotic third generation cephalosporin parenteral agent contains an alkoxyimino substituent =&gt; resistant to ...
  151. 151—Ceftizoxime
    beta lactam antibiotic
    third generation cephalosporin
    parenteral agent
    contains an alkoxyimino substituent => resistant to beta lactamases
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Ceftizoxime beta lactam antibiotic third generation cephalosporin parenteral agent contains an alkoxyimino substituent =&gt; resistant to...
  152. 152—Ceftriaxone
    beta lactam antibiotic
    third generation cephalosporin
    parenteral agent
    contains an alkoxyimino substituent => resistant to beta lactamases
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Biliary excretion
    Ceftriaxone beta lactam antibiotic third generation cephalosporin parenteral agent contains an alkoxyimino substituent =&gt; resistant to...
  153. 153—Ceftazidime
    beta lactam antibiotic
    third generation cephalosporin
    parenteral agent
    contains an alkoxyimino substituent => resistant to beta lactamases
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Ceftazidime beta lactam antibiotic third generation cephalosporin parenteral agent contains an alkoxyimino substituent =&gt; resistant to...
  154. 154—Cefoperazone
    beta lactam antibiotic
    third generation cephalosporin
    parenteral agent
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Biliary excretion
    Cefoperazone beta lactam antibiotic third generation cephalosporin parenteral agent MOA : inhibit cell wall synthesis/similar to penicill...
  155. 155—Cefixime
    beta lactam antibiotic
    third generation cephalosporin
    oral agent
    contains an alkoxyimino substituent => resistant to beta lactamases
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefixime beta lactam antibiotic third generation cephalosporin oral agent contains an alkoxyimino substituent =&gt; resistant to beta lac...
  156. 156—Ceftibuten
    beta lactam antibiotic
    third generation cephalosporin
    oral agent
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Ceftibuten beta lactam antibiotic third generation cephalosporin oral agent MOA : inhibit cell wall synthesis/similar to penicillins : in...
  157. 157—Cefpodoxime proxetil
    beta lactam antibiotic
    third generation cephalosporin
    oral agent
    contains an alkoxyimino substituent => resistant to beta lactamases
    ester prodrug
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefpodoxime proxetil beta lactam antibiotic third generation cephalosporin oral agent contains an alkoxyimino substituent =&gt; resistant...
  158. 158—Cefdinir
    beta lactam antibiotic
    third generation cephalosporin
    oral agent
    contains an alkoxyimino substituent => resistant to beta lactamases
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefdinir beta lactam antibiotic third generation cephalosporin oral agent contains an alkoxyimino substituent =&gt; resistant to beta lac...
  159. 159—Cefditoren pivoxil
    beta lactam antibiotic
    third generation cephalosporin
    oral agent
    contains an alkoxyimino substituent => resistant to beta lactamases
    ester prodrug
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefditoren pivoxil beta lactam antibiotic third generation cephalosporin oral agent contains an alkoxyimino substituent =&gt; resistant t...
  160. 160—Cefepime
    beta lactam antibiotic
    fourth generation cephalosporin
    parenteral agent
    exist as zwitterion
    contains an alkoxyimino substituent => resistant to beta lactamases
    More gram -ve (against P. aeruginosa) and greater beta lactamase resistance
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefepime beta lactam antibiotic fourth generation cephalosporin parenteral agent exist as zwitterion contains an alkoxyimino substituent ...
  161. 161—Cefelidine
    beta lactam antibiotic
    fourth generation cephalosporin
    parenteral agent
    exist as zwitterion
    contains an alkoxyimino substituent => resistant to beta lactamases
    More gram -ve (against P. aeruginosa) and greater beta lactamase resistance
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefelidine beta lactam antibiotic fourth generation cephalosporin parenteral agent exist as zwitterion contains an alkoxyimino substituen...
  162. 162—Cefpirome
    beta lactam antibiotic
    fourth generation cephalosporin
    parenteral agent
    exist as zwitterion
    contains an alkoxyimino substituent => resistant to beta lactamases
    More gram -ve (against P. aeruginosa) and greater beta lactamase resistance
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefpirome beta lactam antibiotic fourth generation cephalosporin parenteral agent exist as zwitterion contains an alkoxyimino substituent...
  163. 163—Cefozopran
    beta lactam antibiotic
    fourth generation cephalosporin
    parenteral agent
    exist as zwitterion
    contains an alkoxyimino substituent => resistant to beta lactamases
    More gram -ve (against P. aeruginosa) and greater beta lactamase resistance
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefozopran beta lactam antibiotic fourth generation cephalosporin parenteral agent exist as zwitterion contains an alkoxyimino substituen...
  164. 164—Cefluprenam
    beta lactam antibiotic
    fourth generation cephalosporin
    parenteral agent
    exist as zwitterion
    contains an alkoxyimino substituent => resistant to beta lactamases
    More gram -ve (against P. aeruginosa) and greater beta lactamase resistance
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Cefluprenam beta lactam antibiotic fourth generation cephalosporin parenteral agent exist as zwitterion contains an alkoxyimino substitue...
  165. 165—Ceftobiprole
    beta lactam antibiotic
    fifth generation cephalosporin
    parenteral agent
    More gram -ve (against P. aeruginosa) and greater beta lactamase resistance
    activity against MRSA
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Ceftobiprole beta lactam antibiotic fifth generation cephalosporin parenteral agent More gram -ve (against P. aeruginosa) and greater bet...
  166. 166—Ceftaroline fosamil
    beta lactam antibiotic
    fifth generation cephalosporin
    parenteral agent
    More gram -ve (against P. aeruginosa) and greater beta lactamase resistance
    activity against MRSA
    MOA : inhibit cell wall synthesis/similar to penicillins : inhibit PBPs & activate autolytic enzymes (inhibit the last stage: stage 3)
    Renal excretion via tubular secretion
    Ceftaroline fosamil beta lactam antibiotic fifth generation cephalosporin parenteral agent More gram -ve (against P. aeruginosa) and grea...
  167. 167—Thienamycin
    beta lactam antibiotic
    carbapeneme
    Natural : streptomyces cattleya
    broad spectrum
    hydroxyethyl at C-6 --> resistant to beta lactamase
    chemically unstable :
    -undergoes beta lactam ring opening => inactive
    -form a dimer => inactive
    MOA : inhibit cell wall synthesis
    Thienamycin beta lactam antibiotic carbapeneme Natural : streptomyces cattleya broad spectrum hydroxyethyl at C-6 --&gt; resistant to bet...
  168. 168—Imipenem
    beta lactam antibiotic
    carbapenem
    addition of N-formiminoyl moiety to Thienamycin --> less Nu
    semi-synthetic
    more chemically stable
    not orally active
    hydrolyzed by dehydropeptidase DHP enzyme in renal tubule => inactive and nephrotoxic metabolites
    formulated with cilastatin (inhibitor of DHP)
    MOA : inhibit cell wall synthesis
    Imipenem beta lactam antibiotic carbapenem addition of N-formiminoyl moiety to Thienamycin --&gt; less Nu semi-synthetic more chemically ...
  169. 169—Meropenem
    beta lactam antibiotic
    carbapeneme
    synthetic
    same activity as Imipenem
    not hydrolyzed by DHP => no need for formulation with cilastatin
    MOA : inhibit cell wall synthesis
    Meropenem beta lactam antibiotic carbapeneme synthetic same activity as Imipenem not hydrolyzed by DHP =&gt; no need for formulation with...
  170. 170—Ertapenem
    beta lactam antibiotic
    carbapenem
    synthetic
    same activity as Imipenem
    not hydrolyzed by DHP => no need for formulation with cilastatin
    MOA : inhibit cell wall synthesis
    Ertapenem beta lactam antibiotic carbapenem synthetic same activity as Imipenem not hydrolyzed by DHP =&gt; no need for formulation with ...
  171. 171—Biapenem
    beta lactam antibiotic
    carbapenem
    synthetic
    same activity as Imipenem
    not hydrolyzed by DHP => no need for formulation with cilastatin
    MOA : inhibit cell wall synthesis
    Biapenem beta lactam antibiotic carbapenem synthetic same activity as Imipenem not hydrolyzed by DHP =&gt; no need for formulation with c...
  172. 172—Aztreonam
    beta lactam antibiotic
    monobactam
    synthetic
    chemically stable for 48h
    strong e-withdrawing sulfamic acid => less stable
    alpha methyl at C2 --> beta lactamase resistant
    given by injection
    active against gram -ve bacteria
    Aztreonam beta lactam antibiotic monobactam synthetic chemically stable for 48h strong e-withdrawing sulfamic acid =&gt; less stable alph...
  173. 173—Tigemonam
    tigemonam
    beta lactam antibiotic
    monobactam
    synthetic
    highly resistant to beta lactamase
    similar spectrum to aztreonam
    orally active, excellent bioavailability
    MOA : inhibit cell wall synthesis
    Tigemonam tigemonam beta lactam antibiotic monobactam synthetic highly resistant to beta lactamase similar spectrum to aztreonam orally a...
  174. 174—Vancomycin
    non beta lactam antibiotic
    glycoprotein, cyclic peptide
    from Nocardia orientalis
    given parenterally
    MOA: inhibit cell wall synthesis through inhibition of transglycosylation step --> inhibition of elongation of peptidoglycan matrix
    active against MRSA
    SE : hypersensitivity / nephro and ototoxicity
    Vancomycin non beta lactam antibiotic glycoprotein, cyclic peptide from Nocardia orientalis given parenterally MOA: inhibit cell wall syn...
  175. 175—Teicoplanin
    non beta lactam antibiotic
    glycoprotein, cyclic peptide
    from Actinoplanes teicomyceticus
    given parenterally
    MOA: inhibit cell wall synthesis through inhibition of transglycosylation step --> inhibition of elongation of peptidoglycan matrix
    active against MRSA
    SE : hypersensitivity / nephrotoxicity
    Teicoplanin non beta lactam antibiotic glycoprotein, cyclic peptide from Actinoplanes teicomyceticus given parenterally MOA: inhibit cell...
  176. 176—Bacitracin
    non beta lactam antibiotic
    cyclic peptide produced from Bacillus subtilis
    inhibits dephosphorylation of the phospholipid carrier responsible for trnsporting the disaccharide across plasma membrane (late stage 1)
    SE: hypersensitivity / nephro and neurotoxicity
    ONLY topical route and IM with caution
    Bacitracin non beta lactam antibiotic cyclic peptide produced from Bacillus subtilis inhibits dephosphorylation of the phospholipid carri...
  177. 177—Cycloserine
    non beta lactam antibiotic
    analog of D-ala produced by streptomyces sp.
    MOA: competitive inhibitor of D-ala-D-ala synthetase and D-ala racemase
    orally active
    SE : - CNS effects : tremor/seizure/confusion/hallucination/psychosis
    - occasional hepatic damage and peripheral neuropathy
    Cycloserine non beta lactam antibiotic analog of D-ala produced by streptomyces sp. MOA: competitive inhibitor of D-ala-D-ala synthetase ...
  178. 178—naphtacenenaphtacene
  179. 179—tetracycline backbonetetracycline backbone
  180. 180—Tetracycline
    Tetracycline antibiotics
    Bacterial protein synthesis inhibitors
    octahydronaphtacene
    Natural (from streptomyces spc) or from chlortetracycline (by hydrogenolysis)
    Crystalline amphoteric compounds (form acid/base salts)
    Low water solubility (HCl salts-->water soluble)
    Orally active
    Undergoes chelation with di/trivalent cations (contraindication with dairy food and antacids)
    -In acidic condition: epimerization:epitetracyclin (4-beta): inactive, -H2O:anhydrotetracycline (deeper color) (double bond on C5a): inactive, formation of epianhydrotetracycline:hepatotoxic
    -In basic condition: lactone formation:isotetracycline: inactive
    Bacteriostatic (higher affinity to bacteria)
    -MOA: active against gram+ and gram-, aerobic and anaerobic-->broad spectrum of activity
    Enter by passive/active diffusion:bind to 30S subunit:inhibit protein synthesis
    -t1/2=6-8h-->short
    widely distributed (low to CSF)
    cross placenta
    excretion: renal
    SE: GI discomfort, discoloration of teeth, hepatotoxic at high dose, vertigo, superinfection
    Tetracycline Tetracycline antibiotics Bacterial protein synthesis inhibitors octahydronaphtacene Natural (from streptomyces spc) or from ...
  181. 181—Demeclocycline
    Tetracycline antibiotics
    Bacterial protein synthesis inhibitors
    octahydronaphtacene
    Natural (from streptomyces spc)
    Crystalline amphoteric compounds (form acid/base salts)
    Low water solubility (HCl salts:water soluble)
    Orally active
    Undergoes chelation with di/trivalent cations (contraindication with dairy food and antacids)
    -In acidic condition: epimerization:epitetracyclin (4-beta): inactive, -H2O:anhydrotetracycline (deeper color) (double bond on C5a): inactive, formation of epianhydrotetracycline:hepatotoxic
    -In basic condition: lactone formation:isotetracycline: inactive
    Bacteriostatic (higher affinity to bacteria)
    -MOA: active against gram+ and gram-, aerobic and anaerobic:broad spectrum of activity
    Enter by passive/active diffusion:bind to 30S subunit-->inhibit protein synthesis
    -t1/2=12h--> intermediate
    widely distributed (low to CSF)
    cross placenta
    excretion: renal
    SE: GI discomfort, discoloration of teeth, hepatotoxic at high dose, vertigo, superinfection, photosensitivity
    Demeclocycline Tetracycline antibiotics Bacterial protein synthesis inhibitors octahydronaphtacene Natural (from streptomyces spc) Crysta...
  182. 182—Minocycline
    Tetracycline antibiotics
    Bacterial protein synthesis inhibitors
    octahydronaphtacene
    Semi-synthetic
    Crystalline amphoteric compounds (form acid/base salts)
    Low water solubility (HCl salts:water soluble)
    Orally active
    Undergoes chelation with di/trivalent cations (contraindication with dairy food and antacids)
    Stable in acidic and basic condition
    More lipophilic
    Bacteriostatic (higher affinity to bacteria)
    MOA: active against gram+ and gram-, aerobic and anaerobic:broad spectrum of activity
    Enter by passive/active diffusion:bind to 30S subunit:inhibit protein synthesis
    t1/2=16h-->long
    completely absorbed
    widely distributed (to CSF:for meningitis)
    cross placenta
    excretion: biliary
    SE: GI discomfort, discoloration of teeth, hepatotoxic at high dose, vertigo, superinfection
    Minocycline Tetracycline antibiotics Bacterial protein synthesis inhibitors octahydronaphtacene Semi-synthetic Crystalline amphoteric com...
  183. 183—Sancycline
    Tetracycline antibiotics
    Bacterial protein synthesis inhibitors
    octahydronaphtacene
    Semi-synthetic
    Slightly more active (than tetracycline)
    Crystalline amphoteric compounds (form acid/base salts)
    Low water solubility (HCl salts:water soluble)
    Orally active
    Undergoes chelation with di/trivalent cations (contraindication with dairy food and antacids)
    Bacteriostatic (higher affinity to bacteria)
    MOA: active against gram+ and gram-, aerobic and anaerobic:broad spectrum of activity
    Enter by passive/active diffusion:bind to 30S subunit:inhibit protein synthesis
    widely distributed (low to CSF)
    cross placenta
    excretion: renal
    SE: GI discomfort, discoloration of teeth, hepatotoxic at high dose, vertigo, superinfection
    Sancycline Tetracycline antibiotics Bacterial protein synthesis inhibitors octahydronaphtacene Semi-synthetic Slightly more active (than ...
  184. 184—Chlortetracycline
    Tetracycline antibiotics
    Bacterial protein synthesis inhibitors
    octahydronaphtacene
    Natural (from streptomyces spc)
    Crystalline amphoteric compounds (form acid/base salts)
    Low water solubility (HCl salts:water soluble)
    Orally active
    Undergoes chelation with di/trivalent cations (contraindication with dairy food and antacids)
    -In acidic condition: epimerization:epitetracyclin (4-beta): inactive, -H2O:anhydrotetracycline (deeper color) (double bond on C5a): inactive, formation of epianhydrotetracycline:hepatotoxic
    -In basic condition: lactone formation:isotetracycline: inactive
    Bacteriostatic (higher affinity to bacteria)
    -MOA: active against gram+ and gram-, aerobic and anaerobic:broad spectrum of activity
    Enter by passive/active diffusion:bind to 30S subunit:inhibit protein synthesis
    t1/2=6-8h -->short
    least absorbed
    widely distributed (low to CSF)
    cross placenta
    excretion: renal
    SE: GI discomfort, discoloration of teeth, hepatotoxic at high dose, vertigo, superinfection
    Chlortetracycline Tetracycline antibiotics Bacterial protein synthesis inhibitors octahydronaphtacene Natural (from streptomyces spc) Cry...
  185. 185—Oxytetracycline
    Tetracycline antibiotics
    Bacterial protein synthesis inhibitors
    octahydronaphtacene
    Natural (from streptomyces spc)
    Crystalline amphoteric compounds (form acid/base salts)
    Low water solubility (HCl salts:water soluble)
    Orally active
    Undergoes chelation with di/trivalent cations (contraindication with dairy food and antacids)
    -In acidic condition: epimerization:epitetracyclin (4-beta): inactive, -H2O:anhydrotetracycline (deeper color) (double bond on C5a): inactive, formation of epianhydrotetracycline:hepatotoxic
    -In basic condition: lactone formation:isotetracycline: inactive
    Bacteriostatic (higher affinity to bacteria)
    -MOA: active against gram+ and gram-, aerobic and anaerobic:broad spectrum of activity
    Enter by passive/active diffusion:bind to 30S subunit:inhibit protein synthesis
    t1/2=6-8h--> short
    widely distributed (low to CSF)
    cross placenta
    excretion: renal
    SE: GI discomfort, discoloration of teeth, hepatotoxic at high dose, vertigo, superinfection
    Oxytetracycline Tetracycline antibiotics Bacterial protein synthesis inhibitors octahydronaphtacene Natural (from streptomyces spc) Cryst...
  186. 186—Methacycline
    Tetracycline antibiotics
    Bacterial protein synthesis inhibitors
    octahydronaphtacene
    Semi-synthetic
    Crystalline amphoteric compounds (form acid/base salts)
    Low water solubility (HCl salts:water soluble)
    Orally active
    Undergoes chelation with di/trivalent cations (contraindication with dairy food and antacids)
    Exception: not stable in acidic and basic condition (undergoes hydration)
    Bacteriostatic (higher affinity to bacteria)
    -MOA: active against gram+ and gram-, aerobic and anaerobic:broad spectrum of activity
    Enter by passive/active diffusion:bind to 30S subunit:inhibit protein synthesis
    t1/2=12h--> intermediate
    widely distributed (low to CSF)
    cross placenta
    excretion: renal
    SE: GI discomfort, discoloration of teeth, hepatotoxic at high dose, vertigo, superinfection
    Methacycline Tetracycline antibiotics Bacterial protein synthesis inhibitors octahydronaphtacene Semi-synthetic Crystalline amphoteric co...
  187. 187—Doxycycline
    Tetracycline antibiotics
    Bacterial protein synthesis inhibitors
    octahydronaphtacene
    Semi-synthetic
    Crystalline amphoteric compounds (form acid/base salts)
    Low water solubility (HCl salts:water soluble)
    Orally active
    Undergoes chelation with di/trivalent cations (contraindication with dairy food and antacids)
    Stable in acidic and basic condition
    More lipophilic
    Bacteriostatic (higher affinity to bacteria)
    -MOA: active against gram+ and gram-, aerobic and anaerobic:broad spectrum of activity
    Enter by passive/active diffusion:bind to 30S subunit:inhibit protein synthesis
    t1/2=16h-->long
    completely absorbed
    widely distributed (low to CSF)
    cross placenta
    excretion: biliary
    SE: GI discomfort, discoloration of teeth, hepatotoxic at high dose, vertigo, superinfection, photosensitivity
    Doxycycline Tetracycline antibiotics Bacterial protein synthesis inhibitors octahydronaphtacene Semi-synthetic Crystalline amphoteric com...
  188. 188—tigecycline
    Tetracycline antibiotics (new)
    Bacterial protein synthesis inhibitors
    9-dimethylglycylamino substituent (DMG)
    Semi-synthetic
    Crystalline amphoteric compounds (form acid/base salts)
    Low water solubility (HCl salts:water soluble)
    Poor oral/ given IV
    Undergoes chelation with di/trivalent cations (contraindication with dairy food and antacids)
    Stable in acidic and basic condition
    More lipophilic
    Bacteriostatic (higher affinity to bacteria)
    -MOA: active against gram+ and gram-, aerobic and anaerobic:broad spectrum of activity
    Enter by passive/active diffusion:bind to 30S subunit (5X more):inhibit protein synthesis
    t1/2=36h--> long
    widely distributed (low to CSF)
    cross placenta/ excreted in milk
    excretion: biliary
    SE: GI discomfort (nausea, vomiting), discoloration of teeth and bone
    tigecycline Tetracycline antibiotics (new) Bacterial protein synthesis inhibitors 9-dimethylglycylamino substituent (DMG) Semi-synthetic ...
  189. 189—streptamine
    diaminoinositol moiety of aminoglycoside
    streptamine diaminoinositol moiety of aminoglycoside
  190. 190—2-deoxystreptamine
    diaminoinositol moiety of aminoglycoside
    2-deoxystreptamine diaminoinositol moiety of aminoglycoside
  191. 191—spectinamine
    diaminoinositol moiety of aminoglycoside
    spectinamine diaminoinositol moiety of aminoglycoside
  192. 192—streptidine
    diaminoinositol moiety of aminoglycoside
    streptidine diaminoinositol moiety of aminoglycoside
  193. 193—Neomycin B
    Aminoglycoside (amino sugar connected to aminocyclitol)
    From streptomyces
    Have a pentose lacking amino group
    Topically, parentarely
    Bactericidal (exception)
    MOA: active against gram- : bind irreversibly to 30S subunit: inhibit bacterial protein synthesis (mistranslation of RNA templates: insertion of wrong amino acid: holes)
    Most toxic
    Active eventhough low plasma level (post antibiotic effect)
    Poor GI absorption
    Poor distribution
    Poor ppb
    Low CSF levels (if no meningitis)
    Accumulation: in renal cortex and inner ear (ototoxicity)
    Cross placenta
    Excretion: renal (unchanged)
    SE: nephrotoxicity/ototoxicity (the higher the nb of amino group: the more toxic), NMJ blockers, teratogenic effect, rare allergic reaction
    Neomycin B Aminoglycoside (amino sugar connected to aminocyclitol) From streptomyces Have a pentose lacking amino group Topically, parent...
  194. 194—gentamycin C
    Aminoglycoside (amino sugar connected to aminocyclitol)
    From micromonospora
    basic, polar, acid (salts)
    Bactericidal (exception)
    MOA: active against gram- : bind irreversibly to 30S subunit: inhibit bacterial protein synthesis (mistranslation of RNA templates: insertion of wrong amino acid: holes)
    Active eventhough low plasma level (post antibiotic effect)
    Poor GI absorption
    Poor distribution
    Poor ppb
    Low CSF levels (if no meningitis)
    Accumulation: in renal cortex and inner ear (ototoxicity)
    Cross placenta
    Excretion: renal (unchanged)
    SE: nephrotoxicity/ototoxicity (the higher the nb of amino group: the more toxic), NMJ blockers, teratogenic effect, rare allergic reaction
    gentamycin C Aminoglycoside (amino sugar connected to aminocyclitol) From micromonospora basic, polar, acid (salts) Bactericidal (excepti...
  195. 195—tobramycin
    Aminoglycoside (amino sugar connected to aminocyclitol)
    From streptomyces
    basic, polar, acid (salts)
    Bactericidal (exception)
    MOA: active against gram- : bind irreversibly to 30S subunit: inhibit bacterial protein synthesis (mistranslation of RNA templates: insertion of wrong amino acid: holes)
    Active eventhough low plasma level (post antibiotic effect)
    Poor GI absorption
    Poor distribution
    Poor ppb
    Low CSF levels (if no meningitis)
    Accumulation: in renal cortex and inner ear (ototoxicity)
    Cross placenta
    Excretion: renal (unchanged)
    SE: nephrotoxicity/ototoxicity (the higher the nb of amino group: the more toxic), NMJ blockers, teratogenic effect, rare allergic reaction
    tobramycin Aminoglycoside (amino sugar connected to aminocyclitol) From streptomyces basic, polar, acid (salts) Bactericidal (exception) ...
  196. 196—neltimicin
    Aminoglycoside (amino sugar connected to aminocyclitol)
    From micromonospora
    basic, polar, acid (salts)
    Bactericidal (exception)
    MOA: active against gram- : bind irreversibly to 30S subunit: inhibit bacterial protein synthesis (mistranslation of RNA templates: insertion of wrong amino acid: holes)
    Active eventhough low plasma level (post antibiotic effect)
    Poor GI absorption
    Poor distribution
    Poor ppb
    Low CSF levels (if no meningitis)
    Accumulation: in renal cortex and inner ear (ototoxicity)
    Cross placenta
    Excretion: renal (unchanged)
    SE: nephrotoxicity/ototoxicity (the higher the nb of amino group: the more toxic), NMJ blockers, teratogenic effect, rare allergic reaction
    neltimicin Aminoglycoside (amino sugar connected to aminocyclitol) From micromonospora basic, polar, acid (salts) Bactericidal (exception...
  197. 197—amikacin
    Aminoglycoside (amino sugar connected to aminocyclitol)
    From micromonospora
    basic, polar, acid (salts)
    Bactericidal (exception)
    MOA: active against gram- : bind irreversibly to 30S subunit: inhibit bacterial protein synthesis (mistranslation of RNA templates: insertion of wrong amino acid: holes)
    Active eventhough low plasma level (post antibiotic effect)
    Poor GI absorption
    Poor distribution
    Poor ppb
    Low CSF levels (if no meningitis)
    Accumulation: in renal cortex and inner ear (ototoxicity)
    Cross placenta
    Excretion: renal (unchanged)
    SE: nephrotoxicity/ototoxicity (the higher the nb of amino group: the more toxic), NMJ blockers, teratogenic effect, rare allergic reaction
    amikacin Aminoglycoside (amino sugar connected to aminocyclitol) From micromonospora basic, polar, acid (salts) Bactericidal (exception) ...
  198. 198—kanamycin A
    old Aminoglycoside (amino sugar connected to aminocyclitol)
    From streptomyces
    basic, polar, acid (salts)
    Bactericidal (exception)
    MOA: active against gram- : bind irreversibly to 30S subunit: inhibit bacterial protein synthesis (mistranslation of RNA templates: insertion of wrong amino acid: holes)
    Active eventhough low plasma level (post antibiotic effect)
    Poor GI absorption
    Poor distribution
    Poor ppb
    Low CSF levels (if no meningitis)
    Accumulation: in renal cortex and inner ear (ototoxicity)
    Cross placenta
    Excretion: renal (unchanged)
    SE: nephrotoxicity/ototoxicity (the higher the nb of amino group: the more toxic), NMJ blockers, teratogenic effect, rare allergic reaction
    kanamycin A old Aminoglycoside (amino sugar connected to aminocyclitol) From streptomyces basic, polar, acid (salts) Bactericidal (except...
  199. 199—Macrolides
    Bacterial protein synthesis inhibitor
    large-membered lactone rings
    14 or 15-membered rings attached to deoxy sugars
    from propionic acid units
    substituted amino group on sugar → weakly basic (pKa = 8)
    not very water soluble
    salt formation with glucoheptanoic and lactobionic acids increase water soluble
    stearate and laurylsulfate salts decrease water solubility
    Macrolides Bacterial protein synthesis inhibitor large-membered lactone rings 14 or 15-membered rings attached to deoxy sugars from propi...
  200. 200—Erythromycin
    macrolide
    natural (from Streptomyces erythreus)
    bacteriostatic
    active against gram+, aerobic
    well distributed (except to brain, CSF)
    cross placenta
    found in breast milk
    penetrates the prostatic fluid
    MOA: bind to 50S (reversibly): inhibit protein synthesis
    More effective at alkaline pH
    Free base form: inactivated by gastric acid, form cyclic ketal (given as enteric coated)
    Stearate: slightly susceptible to gastric acid inactivation
    ethylsuccinate preparation: absorbed first and hydrolyzed in blood to liberate free erythromycin
    estolate preparation (laurylsulfate propionate): more acid resistant
    lactobionate: suitable for IV administration
    t1/2= 1.2-2h
    enterohepatic circulation
    metabolism: partially
    excretion: biliary (95% in active form)
    SE: safe, GI disturbances (nausea, vomiting, anorexia, diarrhea, abdominal cramps), cholestatic hepatitis (with estolate ester), rare allergic reaction, ototoxicity (reversible at high dose)
    DDI: CYP3A4 inhibitor
    CI: with liver dysfunction patients
    Erythromycin macrolide natural (from Streptomyces erythreus) bacteriostatic active against gram+, aerobic well distributed (except to bra...

Information

Description
Flashcards on med chem 2 final exam, created by lola_smily on 04/05/2015.
Created by
lola_smily · May 2015
Updated
May 1, 2019
Views
1,965
Rating
Average rating 5.0 out of 5 (1 rating)

Feedback

What is it about?

What do you think of the new look?

How do you like it?